@@ -5,6 +5,7 @@ import uuid
 from dvc.testing.cloud import Cloud
 from dvc.testing.path_info import CloudURLInfo
 
+TEST_OSS_ENDPOINT = "oss-us-east-1.aliyuncs.com"
 TEST_OSS_REPO_BUCKET = "dvc-test-github"
 
 
@@ -22,7 +23,7 @@ class OSS(Cloud, CloudURLInfo):
             "url": self.url,
             "oss_key_id": os.environ.get("OSS_ACCESS_KEY_ID"),
             "oss_key_secret": os.environ.get("OSS_ACCESS_KEY_SECRET"),
-            "oss_endpoint": os.environ.get("OSS_ENDPOINT"),
+            "oss_endpoint": TEST_OSS_ENDPOINT,
         }
 
     def is_file(self):
